import random
import fakedata.lista as lista

class FakeData:

    def RandomOneName():
        """Devuelve un nombre aleatoreamente en el siguiente formato:
        nombre apellido apellido
        
        Returns
        -------
        name : str
            Cadena que contiene el nombre generado
        """
        sex = random.choice(['male', 'female'])
        if sex == 'male':
            name = random.choice(lista.name_m) + " " + random.choice(lista.last_names) + " " + random.choice(lista.last_names)
            return name.title()
        elif sex == 'female':
            name = random.choice(lista.name_f) + " " + random.choice(lista.last_names) + " " + random.choice(lista.last_names)
            return name.title()
        
    def RandomTwoName():
        """Devuelve un nombre aleatoreamente en el siguiente formato:
        nombre nombre apellido apellido
        
        Returns
        -------
        name : str
            Cadena que contiene el nombre generado
        """
        sex = random.choice(['male', 'female'])
        if sex == 'male':
            name = random.choice(lista.name_m) + " " + random.choice(lista.name_m) + " " +random.choice(lista.last_names) + " " + random.choice(lista.last_names)
            return name.title()
        elif sex == 'female':
            name = random.choice(lista.name_f) + " " + random.choice(lista.name_f) + " " +random.choice(lista.last_names) + " " + random.choice(lista.last_names)
            return name.title()
        
    def RandomUSAName():
        sex = random.choice(['male', 'female'])
        if sex == 'male':
            name = random.choice(lista.name_m) + " " + random.choice(lista.name_m) + " " +random.choice(lista.last_names)
            return name.title()
        elif sex == 'female':
            name = random.choice(lista.name_f) + " " + random.choice(lista.name_f) + " " +random.choice(lista.last_names)
            return name.title()
        
    def RandomName():
        """Devuelve un nombre aleatoreamente de los siguientes formatos:
        nombre nombre apellido apellido
        nombre apellido apellido
        
        Returns
        -------
        name : str
            Cadena que contiene el nombre generado
        """
        name_length = random.choice([1, 2])
        if name_length == 1:
            name = FakeData.RandomOneName()
            return name
        elif name_length == 2:
            name = FakeData.RandomTwoName()
            return name
    
    def CheckSex(name):
        """Devuelve el genero del nombre proporcionado. Esta funcion solo funciona
        con los nombres generados por las funciones:
        RandomOneName()
        RandomTwoName()
        RandomName()
        
        Returns
        -------
        sex : str
            Cadena que contiene el sexo del nombre proporcionado puede ser:
            male
            female
        """
        name_list = name.split(' ')
        if name_list[0].upper() in lista.name_m:
            return 'male'
        elif name_list[0].upper() in lista.name_f:
            return 'female'
        else:
            return 'El nombre no esta en la lista, si quieres un sexo random utiliza: RandomSex'
        
    def RandomSex():
        return random.choice(['male', 'female'])
        
    def RandomEmail(nombre):
        """Devuelve un email al pasarle un nombre
        Parameters
        ----------
        nombre : str
            Cadena que contendra el nombre del cual se generara un email
        Returns
        -------
        email : str
            Cadena que contiene el email generado
        """
        servers = [
            'gmail',
            'outlook',
            'yahoo',
            'yopmail'
        ]
        dot = [
            '.com',
            '.net',
            '.es',
            '.mx',
        ]
        list_name = nombre.split(' ')
        num_name = len(list_name)
        if num_name >= 5:
            first_name = list_name[0]
            first_letter_name = first_name[0]
            last_name_ma = list_name[3]
            last_name_fa = list_name[4]
            first_letter_last_fa = last_name_fa[0]
            user = (first_letter_name + last_name_ma +
                    first_letter_last_fa).lower()
            email = user + '@' + random.choice(servers) + random.choice(dot)
            return email
        if num_name == 4:
            first_name = list_name[0]
            first_letter_name = first_name[0]
            last_name_ma = list_name[2]
            last_name_fa = list_name[3]
            first_letter_last_fa = last_name_fa[0]
            user = (first_letter_name + last_name_ma +
                    first_letter_last_fa).lower()
            email = user + '@' + random.choice(servers) + random.choice(dot)
            return email
        elif num_name == 3:
            first_name = list_name[0]
            first_letter_name = first_name[0]
            last_name_ma = list_name[1]
            last_name_fa = list_name[2]
            first_letter_last_fa = last_name_fa[0]
            user = (first_letter_name + last_name_ma +
                    first_letter_last_fa).lower()
            email = user + '@' + random.choice(servers) + random.choice(dot)
            return email
        elif num_name == 2:
            first_name = list_name[0]
            first_letter_name = first_name[0]
            last_name_ma = list_name[1]
            user = (first_letter_name + last_name_ma).lower()
            email = user + '@' + random.choice(servers) + random.choice(dot)
            return email
        elif num_name == 1:
            first_name = list_name[0]
            user = (first_name).lower()
            email = user + '@' + random.choice(servers) + random.choice(dot)
            return email

    def PersonalizedEmail(nombre, servidor_web):
        """Devuelve un email al pasarle un nombre
        Parameters
        ----------
        nombre : str
            Cadena que contendra el nombre del cual se generara un email.
            Ejemplo: Jose Angel Colin Najera
        servidor_web : str
            Cadena que contendra el servidor con el que cuente el email.
            Ejemplo: gmail.com
        Returns
        -------
        email : str
            Cadena que contiene el email generado
        """
        list_name = nombre.split(' ')
        num_name = len(list_name)
        if num_name >= 5:
            first_name = list_name[0]
            first_letter_name = first_name[0]
            last_name_ma = list_name[3]
            last_name_fa = list_name[4]
            first_letter_last_fa = last_name_fa[0]
            user = (first_letter_name + last_name_ma +
                    first_letter_last_fa).lower()
            email = user + '@' + servidor_web
            return email
        if num_name == 4:
            first_name = list_name[0]
            first_letter_name = first_name[0]
            last_name_ma = list_name[2]
            last_name_fa = list_name[3]
            first_letter_last_fa = last_name_fa[0]
            user = (first_letter_name + last_name_ma +
                    first_letter_last_fa).lower()
            email = user + '@' + servidor_web
            return email
        elif num_name == 3:
            first_name = list_name[0]
            first_letter_name = first_name[0]
            last_name_ma = list_name[1]
            last_name_fa = list_name[2]
            first_letter_last_fa = last_name_fa[0]
            user = (first_letter_name + last_name_ma +
                    first_letter_last_fa).lower()
            email = user + '@' + servidor_web
            return email
        elif num_name == 2:
            first_name = list_name[0]
            first_letter_name = first_name[0]
            last_name_ma = list_name[1]
            user = (first_letter_name + last_name_ma).lower()
            email = user + '@' + servidor_web
            return email
        elif num_name == 1:
            first_name = list_name[0]
            user = (first_name).lower()
            email = user + '@' + servidor_web
            return email
        
    def RandomTel():
        tel = []
        new_tel = ''
        x = 0
        while x!= 10:
            new_tel += str(random.choice(range(0,10)))
            x += 1
        return new_tel

if __name__ == '__main__':
    data = FakeData
    x = 0
    while x != 100:
        nombreRandom = data.RandomName()
        sex = data.CheckSex(nombreRandom)
        nombreOne = data.RandomOneName()
        sexOne = data.CheckSex(nombreOne)
        nombreTwo = data.RandomTwoName()
        sexTwo = data.CheckSex(nombreTwo)
        email = data.RandomEmail(nombreRandom)
        emailPersonalizado = data.PersonalizedEmail(nombreRandom, 'outlook.com')
        sexRandom = data.RandomSex()
        tel = data.RandomTel()
        print("".center(50, '-'))
        print(f'Nombre ramdom: {nombreRandom}')
        print(f'Email random: {email}')
        print(f'Sexo : {sex}')
        print(f'Email personalizado: {emailPersonalizado}')
        print(f'Un solo nombre: {nombreOne}')
        print(f'Sexo One: {sexOne}')
        print(f'Dos nombre: {nombreTwo}')
        print(f'Sexo Two: {sexTwo}')
        print(f'Sexo Random: {sexRandom}')
        print(f'Telefono: {tel}')
        print("".center(50, '-'))
        x += 1
        




name_m = [
    'JOSE',
    'ANTONIO',
    'JUAN',
    'MANUEL',
    'FRANCISCO',
    'LUIS',
    'JAVIER',
    'MIGUEL',
    'CARLOS',
    'ANGEL',
    'JESUS',
    'DAVID',
    'DANIEL',
    'PEDRO',
    'ALEJANDRO',
    'MARIA',
    'ALBERTO',
    'RAFAEL',
    'PABLO',
    'FERNANDO',
    'JORGE',
    'RAMON',
    'SERGIO',
    'ENRIQUE',
    'ANDRES',
    'DIEGO',
    'VICENTE',
    'ADRIAN',
    'VICTOR',
    'ALVARO',
    'IGNACIO',
    'RAUL',
    'EDUARDO',
    'IVAN',
    'OSCAR',
    'RUBEN',
    'JOAQUIN',
    'SANTIAGO',
    'MARIO',
    'ROBERTO',
    'GABRIEL',
    'ALFONSO',
    'JAIME',
    'MARCOS',
    'RICARDO',
    'JULIO',
    'EMILIO',
    'HUGO',
    'SALVADOR',
    'GUILLERMO',
    'MARTIN',
    'MOHAMED',
    'TOMAS',
    'JULIAN',
    'JORDI',
    'NICOLAS',
    'AGUSTIN',
    'GONZALO',
    'CRISTIAN',
    'FELIX',
    'CESAR',
    'MARC',
    'JOSEP',
    'JOAN',
    'SEBASTIAN',
    'SAMUEL',
    'FELIPE',
    'DOMINGO',
    'HECTOR',
    'ISMAEL',
    'ALFREDO',
    'LUCAS',
    'MARIANO',
    'AITOR',
    'ALEX',
    'RODRIGO',
    'IKER',
    'ALEXANDER',
    'XAVIER',
    'ESTEBAN',
    'MATEO',
    'MARCO',
    'GREGORIO',
    'ARTURO',
    'LORENZO',
    'ALBERT',
    'BORJA',
    'EUGENIO',
    'CRISTOBAL',
    'JOEL',
    'AARON',
    'DARIO',
    'ISAAC',
    'JONATHAN',
    'CHRISTIAN',
    'GERMAN',
    'VALENTIN',
    'ADOLFO',
    'ERIC',
    'PAU'
]

name_f = [
    'MARIA',
    'CARMEN',
    'ANA',
    'ISABEL',
    'DOLORES',
    'PILAR',
    'TERESA',
    'ROSA',
    'JOSEFA',
    'CRISTINA',
    'ANGELES',
    'LAURA',
    'ANTONIA',
    'ELENA',
    'MARTA',
    'LUCIA',
    'FRANCISCA',
    'MERCEDES',
    'LUISA',
    'CONCEPCION',
    'ROSARIO',
    'JOSE',
    'PAULA',
    'SARA',
    'RAQUEL',
    'JUANA',
    'ROCIO',
    'EVA',
    'MANUELA',
    'BEATRIZ',
    'PATRICIA',
    'VICTORIA',
    'JESUS',
    'JULIA',
    'ANDREA',
    'BELEN',
    'SILVIA',
    'ALBA',
    'ESTHER',
    'ENCARNACION',
    'NURIA',
    'IRENE',
    'MONTSERRAT',
    'ANGELA',
    'SANDRA',
    'MONICA',
    'INMACULADA',
    'ALICIA',
    'YOLANDA',
    'SONIA',
    'MAR',
    'MARINA',
    'MARGARITA',
    'SUSANA',
    'SOFIA',
    'NATALIA',
    'CLAUDIA',
    'CAROLINA',
    'INES',
    'AMPARO',
    'GLORIA',
    'ALEJANDRA',
    'VERONICA',
    'NIEVES',
    'CARLA',
    'LOURDES',
    'DANIELA',
    'SOLEDAD',
    'LUZ',
    'NOELIA',
    'LORENA',
    'BEGOÑA',
    'FATIMA',
    'OLGA',
    'BLANCA',
    'CONSUELO',
    'ASUNCION',
    'NEREA',
    'MIRIAM',
    'MILAGROS',
    'ESPERANZA',
    'CLARA',
    'LIDIA',
    'CATALINA',
    'CELIA',
    'AURORA',
    'ANNA',
    'ADRIANA',
    'MAGDALENA',
    'MARTINA',
    'EMILIA',
    'ELISA',
    'VANESA',
    'EUGENIA',
    'VIRGINIA',
    'AINHOA',
    'GEMA',
    'JOSEFINA',
    'DIANA',
    'ALEXANDRA'
]

last_names = [
    'García',
    'González',
    'Rodríguez',
    'Fernández',
    'López',
    'Martínez',
    'Sánchez',
    'Pérez',
    'Gómez',
    'Martin',
    'Jiménez',
    'Ruiz',
    'Hernández',
    'Diaz',
    'Moreno',
    'Muñoz',
    'Álvarez',
    'Romero',
    'Alonso',
    'Gutiérrez',
    'Navarro',
    'Torres',
    'Domínguez',
    'Vázquez',
    'Ramos',
    'Gil',
    'Ramírez',
    'Serrano',
    'Blanco',
    'Molina',
    'Morales',
    'Suarez',
    'Ortega',
    'Delgado',
    'Castro',
    'Ortiz',
    'Rubio',
    'Marín',
    'Sanz',
    'Núñez',
    'Iglesias',
    'Medina',
    'Garrido',
    'Cortes',
    'Castillo',
    'Santos',
    'Lozano',
    'Guerrero',
    'Cano',
    'Prieto',
    'Méndez',
    'Cruz',
    'Calvo',
    'Gallego',
    'Vidal',
    'León',
    'Márquez',
    'Herrera',
    'Peña',
    'Flores',
    'Cabrera',
    'Campos',
    'Vega',
    'Fuentes',
    'Carrasco',
    'Diez',
    'Caballero',
    'Reyes',
    'Nieto',
    'Aguilar',
    'Pascual',
    'Santana',
    'Herrero',
    'Lorenzo',
    'Montero',
    'Hidalgo',
    'Giménez',
    'Ibáñez',
    'Ferrer',
    'Duran',
    'Santiago',
    'Benítez',
    'Mora',
    'Vicente',
    'Vargas',
    'Arias',
    'Carmona',
    'Crespo',
    'Román',
    'Pastor',
    'Soto',
    'Sáez',
    'Velasco',
    'Moya',
    'Soler',
    'Parra',
    'Esteban',
    'Bravo',
    'Gallard',
    'Rojas'
]


from fakedata.fakedata import FakeData

RandomOneName = FakeData.RandomOneName
RandomTwoName = FakeData.RandomTwoName
RandomUSAName = FakeData.RandomUSAName
RandomName = FakeData.RandomName
CheckSex = FakeData.CheckSex
RandomSex = FakeData.RandomSex
RandomEmail = FakeData.RandomEmail
PersonalizedEmail = FakeData.PersonalizedEmail



import logging
from fakedata.fakedata import FakeData

logging.basicConfig(level=logging.DEBUG)


def main(data):
    nombreRandom = data.RandomName()
    sex = data.CheckSex(nombreRandom)
    nombreOne = data.RandomOneName()
    sexOne = data.CheckSex(nombreOne)
    nombreTwo = data.RandomTwoName()
    sexTwo = data.CheckSex(nombreTwo)
    email = data.RandomEmail(nombreRandom)
    emailPersonalizado = data.PersonalizedEmail(nombreRandom, 'outlook.com')
    sexRandom = data.RandomSex()
    tel = data.RandomTel()
    
    print(f'Nombre ramdom: {nombreRandom}')
    print(f'Email random: {email}')
    print(f'Sexo : {sex}')
    print(f'Email personalizado: {emailPersonalizado}')
    print(f'Un solo nombre: {nombreOne}')
    print(f'Sexo One: {sexOne}')
    print(f'Dos nombre: {nombreTwo}')
    print(f'Sexo Two: {sexTwo}')
    print(f'Sexo Random: {sexRandom}')
    print(f'Telefono: {tel}')

if __name__ == '__main__':
    data = FakeData
    x = 0
    while x != 1:
        logging.debug("Ejecutando pruebas FakeData".center(50, '-'))
        main(data)
        logging.debug("Finalizando pruebas FakeData".center(50, '-'))
        x += 1
        


import imp
from pathlib import Path
from setuptools import setup

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

VERSION = '0.3'
DESCRIPTION = 'A python package for data fake generation'
PACKAGE_NAME = 'fakedata'
AUTHOR = 'Jose Angel Colin Najera'
EMAIL = 'josecolin99@gmail.com'
GITHUB_URL = 'https://github.com/Josecolin99/FakeData'

setup(
    name = PACKAGE_NAME,
    packages = [PACKAGE_NAME],
    entry_points={
        "console_scripts":
            ["fakedata=fakedata.__main__:main"]
    },
    version = VERSION,
    license='MIT',
    description = DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    author = AUTHOR,
    author_email = EMAIL,
    url = GITHUB_URL,
    keywords = [
        'FakeData',
        'Fake Data',
        'fakedata',
        'faked ata',
        'Data',
        'data'
    ],
    install_requires=[ 
        
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
)